#!/bin/bash
# /bin/sh enables POSIX mode
# /bin/bash disables POSIX mode <<<

if [ ${UID} -ne 0 ]
then
	echo 'This script must be run as root.'
	echo "Exit script by error."
	exit
fi

DESTDIR="/opt"
NEWTOPDIR="hoststatedir"
PROGRAM="hoststate"
CHILDPROGRAM1="icmppipegnu"
REFFILE1="hostlist"
UNINSTALLSHELL="uninstall.sh"
READMEFILE1="readme_e"
READMEFILE2="readme_j"
ICOTEMP="hoststate64.ico"

ICONDIR="/usr/share/icons/hicolor/scalable/apps"
ICONFILE="hoststate.svg"

DESKTOPDIR="/usr/share/applications"
DESKTOPFILE="hoststate.desktop"



if [ $# -gt 1 ]
then
	echo "$# arguments too mouch. (<=1)"
	exit
elif [ $# -eq 1 ]
then
	echo "You specified new install destination \"$1\" ." 
	DESTDIR=$1
fi

echo "$0 is started." # $_ is for POSIX
echo "Destination directory is \"${DESTDIR}\"."
echo "New top directory to create is \"${NEWTOPDIR}\"."
echo "So, main files will be copied to \"${DESTDIR}/${NEWTOPDIR}/\"."
echo "Processing ..."



if [ ! -e "${DESTDIR}/${NEWTOPDIR}" ]; then
	echo "  ${DESTDIR}/${NEWTOPDIR} is not exist."
	sudo mkdir -p "${DESTDIR}/${NEWTOPDIR}"
	echo "  ${DESTDIR}/${NEWTOPDIR} is created."
elif [ -f "${DESTDIR}/${NEWTOPDIR}" ]; then
		echo "${DESTDIR}/${NEWTOPDIR} is a file."
		echo "Exit script by error."
		exit
fi
chmod 755 "${DESTDIR}/${NEWTOPDIR}"
echo "  Directory ${DESTDIR}/${NEWTOPDIR} is with 755."

cp ${PROGRAM} "${DESTDIR}/${NEWTOPDIR}/"
chmod 711 "${DESTDIR}/${NEWTOPDIR}/${PROGRAM}"
echo "  Binary ${DESTDIR}/${NEWTOPDIR}/${PROGRAM} is copied with 711."

cp ${CHILDPROGRAM1} "${DESTDIR}/${NEWTOPDIR}/"
chmod 711 "${DESTDIR}/${NEWTOPDIR}/${CHILDPROGRAM1}"
echo "  Binary ${DESTDIR}/${NEWTOPDIR}/${CHILDPROGRAM1} is copied with 711."
setcap cap_net_raw=eip "${DESTDIR}/${NEWTOPDIR}/${CHILDPROGRAM1}"
echo "  Set net-raw-capability to Binary ${DESTDIR}/${NEWTOPDIR}/${CHILDPROGRAM1}."

cp ${REFFILE1} "${DESTDIR}/${NEWTOPDIR}/"
chmod 666 "${DESTDIR}/${NEWTOPDIR}/${REFFILE1}"
echo "  Reference file ${DESTDIR}/${NEWTOPDIR}/${REFFILE1} is copied with 666."

cp ${UNINSTALLSHELL} "${DESTDIR}/${NEWTOPDIR}/"
chmod 755 "${DESTDIR}/${NEWTOPDIR}/${UNINSTALLSHELL}"
echo "  Shell ${DESTDIR}/${NEWTOPDIR}/${UNINSTALLSHELL} is copied with 755."

cp ${READMEFILE1} "${DESTDIR}/${NEWTOPDIR}/"
chmod 644 "${DESTDIR}/${NEWTOPDIR}/${READMEFILE1}"
echo "  Readme file ${DESTDIR}/${NEWTOPDIR}/${READMEFILE1} is copied with 644."

cp ${READMEFILE2} "${DESTDIR}/${NEWTOPDIR}/"
chmod 644 "${DESTDIR}/${NEWTOPDIR}/${READMEFILE2}"
echo "  Readme file ${DESTDIR}/${NEWTOPDIR}/${READMEFILE2} is copied with 644."

cp ${ICOTEMP} "${DESTDIR}/${NEWTOPDIR}/"
chmod 644 "${DESTDIR}/${NEWTOPDIR}/${ICOTEMP}"
echo "  IconPng file ${DESTDIR}/${NEWTOPDIR}/${ICOTEMP} is copied with 644."



if [ ! -e ${ICONDIR} ]; then
	echo "  ${ICONDIR} is not exist."
	sudo mkdir -p ${ICONDIR}
	echo "  ${ICONDIR} is created."
elif [ -f ${ICONDIR} ]; then
		echo "${ICONDIR} is a file."
		echo "Exit script by error."
		exit
fi
cp ${ICONFILE} "${ICONDIR}/"
chmod 644 "${ICONDIR}/${ICONFILE}"
echo "  Icon ${ICONDIR}/${ICONFILE} is copied with 644."



if [ ! -e ${DESKTOPDIR} ]; then
	echo "  ${DESKTOPDIR} is not exist."
	sudo mkdir -p ${DESKTOPDIR}
	echo "  ${DESKTOPDIR} is created."
elif [ -f ${DESKTOPDIR} ]; then
		echo "${DESKTOPDIR} is a file."
		echo "Exit script by error."
		exit
fi
cp ${DESKTOPFILE} "${DESKTOPDIR}/"
chmod 755 "${DESKTOPDIR}/${DESKTOPFILE}"
echo "  Desktop-File ${DESKTOPDIR}/${DESKTOPFILE} is copied with 755."



echo "Done."
echo ""


